var api = require("../../utils/api-connector");
var chai = require('chai');
var assert = chai.assert;

describe("API Connector", function () {
  it('each API request should respond no later than 3s', function (done) {
    this.timeout(3000);

    Promise.all(mapAPIMethods(testSimpleCall)).then(function () {
      done();
    });

    function testSimpleCall(method) {
      return getRequestPromise(method);
    }
  });

  it(`each API method should call callback function with response status code`, function (done) {
    this.timeout(0);

    var requests = mapAPIMethods(function (method) {
      return getRequestPromise(method, function (error, response) {
        assert.isNumber(response.statusCode, `api.${method} response.statusCode doesn't not exist`);
      });
    });

    Promise.all(requests).then(function () {
      done();
    });
  });

  function mapAPIMethods(call) {
    return Object.keys(api).map(call);
  }

  function getRequestPromise(method, callback = function () {}) {
    return new Promise(function (resolve) {
      api[method]({}, function (error, response, body) {
        callback(error, response, body);
        resolve();
      });
    });
  }
});